<?php

/**
 * This is the model class for table "pemadaman".
 *
 * The followings are the available columns in table 'pemadaman':
 * @property integer $id
 * @property integer $user_id
 * @property integer $sites_id
 * @property string $degon
 * @property string $degoff
 * @property string $keterangan
 * @property integer $genoperasi
 *
 * The followings are the available model relations:
 * @property Sites $sites
 * @property User $user
 */
class Pemadaman extends CActiveRecord
{
	public $timeDifference;
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Pemadaman the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pemadaman';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('sites_id, degon, degoff, keterangan, genoperasi', 'required'),
			array('genoperasi', 'numerical', 'integerOnly'=>true),
			array('degon, degoff', 'length', 'max'=>20),
			array('keterangan', 'length', 'max'=>200),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, user_id, sites_id, degon, degoff, keterangan, genoperasi', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'sites' => array(self::BELONGS_TO, 'Sites', 'sites_id'),
			'user' => array(self::BELONGS_TO, 'User', 'user_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'user_id' => 'Petugas yang melapor',
			'sites_id' => 'STO/Site',
			'degon' => 'DEG ON',
			'degoff' => 'DEG OFF',
			'keterangan' => 'Keterangan',
			'genoperasi' => 'Genset Yang Operasi',
		);
	}
	protected function beforeSave()
{
    list($c_date, $c_time) = explode(' ', $this->degon);
    list($c_d, $c_m, $c_y) = explode('/', $c_date);
    list($c_h, $c_i) = explode(':', $c_time);
    $this->degon = date('Y-m-d H:i:s', mktime($c_h, $c_i, 0, $c_m, $c_d, $c_y));
    list($c_date, $c_time) = explode(' ', $this->degoff);
    list($c_d, $c_m, $c_y) = explode('/', $c_date);
    list($c_h, $c_i) = explode(':', $c_time);
    $this->degoff = date('Y-m-d H:i:s', mktime($c_h, $c_i, 0, $c_m, $c_d, $c_y));
    return parent::beforeSave();
}

protected function afterFind()
{
    $this->degon = date('Y-m-d H:i:s', strtotime($this->degon));
    $this->degoff = date('Y-m-d H:i:s', strtotime($this->degoff));
    return parent::afterFind();
}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;
		
		$criteria->compare('id',$this->id);
		$criteria->compare('user_id',$this->user_id);
		$criteria->compare('sites_id',$this->sites_id);
		$criteria->compare('degon',$this->degon,true);
		$criteria->compare('degoff',$this->degoff,true);
		$criteria->compare('keterangan',$this->keterangan,true);
		$criteria->compare('genoperasi',$this->genoperasi);
		$criteria->select = 'TIME_TO_SEC(TIMEDIFF(degoff, degon)) AS timeDifference';
		
		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}